package com.ruoyi.manage.service;

import com.ruoyi.manage.domain.TaskManage;

import java.util.List;

/**
 * 任务管理Service接口
 * 
 * @author boman
 * @date 2025-05-07
 */
public interface ITaskManageService 
{
    /**
     * 查询任务管理
     * 
     * @param taskId 任务管理主键
     * @return 任务管理
     */
    public TaskManage selectTaskManageByTaskId(Long taskId);

    /**
     * 查询任务管理列表
     * 
     * @param taskManage 任务管理
     * @return 任务管理集合
     */
    public List<TaskManage> selectTaskManageList(TaskManage taskManage);

    /**
     * 新增任务管理
     * 
     * @param taskManage 任务管理
     * @return 结果
     */
    public int insertTaskManage(TaskManage taskManage);

    /**
     * 修改任务管理
     * 
     * @param taskManage 任务管理
     * @return 结果
     */
    public int updateTaskManage(TaskManage taskManage);

    /**
     * 批量删除任务管理
     * 
     * @param taskIds 需要删除的任务管理主键集合
     * @return 结果
     */
    public int deleteTaskManageByTaskIds(Long[] taskIds);

    /**
     * 删除任务管理信息
     * 
     * @param taskId 任务管理主键
     * @return 结果
     */
    public int deleteTaskManageByTaskId(Long taskId);
}
